@@ -35,6 +35,8 @@ from czitools.metadata_tools.detector import CziDetector
 from czitools.utils.box import get_czimd_box
 from czitools.metadata_tools.helper import DictObj
 
+import contextlib
+
 logger = logging_tools.set_logging()
 
 
@@ -42,6 +44,7 @@ logger = logging_tools.set_logging()
 class CziMetadata:
     """
     CziMetadata class for handling metadata of CZI image files.
+
     Attributes:
         filepath (Union[str, os.PathLike[str]]): Path to the CZI image file.
         filename (Optional[str]): Name of the CZI image file.
@@ -50,6 +53,8 @@ class CziMetadata:
         software_name (Optional[str]): Name of the software used for acquisition.
         software_version (Optional[str]): Version of the software used for acquisition.
         acquisition_date (Optional[str]): Date and time of image acquisition.
+        creation_date (Optional[str]): Date and time of image creation.
+        user_name (Optional[str]): Name of the user who created the image.
         czi_box (Optional[Box]): Metadata box of the CZI file.
         pyczi_dims (Optional[Dict[str, tuple]]): Dimensions of the CZI file.
         aics_dimstring (Optional[str]): Dimension string from aicspylibczi.
@@ -61,13 +66,14 @@ class CziMetadata:
         aics_dim_valid (Optional[int]): Number of valid dimensions from aicspylibczi.
         aics_posC (Optional[int]): Position of the 'C' dimension from aicspylibczi.
         pixeltypes (Optional[Dict[int, str]]): Pixel types for all channels.
-        isRGB (Optional[bool]): Indicates if the image is RGB.
+        consistent_pixeltypes (Optional[bool]): Indicates if pixel types are consistent across channels.
+        isRGB (Optional[Dict[int, bool]]): Indicates if the image is RGB.
         has_scenes (Optional[bool]): Indicates if the CZI file has scenes.
         has_label (Optional[bool]): Indicates if the CZI file has a label image.
         has_preview (Optional[bool]): Indicates if the CZI file has a preview image.
         attachments (Optional[CziAttachments]): Attachments in the CZI file.
-        npdtype (Optional[List[Any]]): Numpy data types for pixel values.
-        maxvalue (Optional[List[int]]): Maximum values for pixel types.
+        npdtype_list (Optional[List[Any]]): Numpy data types for pixel values.
+        maxvalue_list (Optional[List[int]]): Maximum values for pixel types.
         image (Optional[CziDimensions]): Dimensions of the CZI image.
         bbox (Optional[CziBoundingBox]): Bounding box of the CZI image.
         channelinfo (Optional[CziChannelInfo]): Information about channels.
@@ -77,8 +83,9 @@ class CziMetadata:
         microscope (Optional[CziMicroscope]): Microscope information.
         sample (Optional[CziSampleInfo]): Sample information.
         add_metadata (Optional[CziAddMetaData]): Additional metadata.
-        array6d_size (Optional[Tuple[int]]): Size of the 6D array.
         scene_size_consistent (Optional[Tuple[int]]): Consistency of scene sizes.
+        verbose (bool): Verbose output for logging.
+
     Methods:
         __post_init__(): Initializes the CziMetadata object after dataclass initialization.
     """
@@ -90,6 +97,8 @@ class CziMetadata:
     software_name: Optional[str] = field(init=False, default=None)
     software_version: Optional[str] = field(init=False, default=None)
     acquisition_date: Optional[str] = field(init=False, default=None)
+    creation_date: Optional[str] = field(init=False, default=None)
+    user_name: Optional[str] = field(init=False, default=None)
     czi_box: Optional[Box] = field(init=False, default=None)
     pyczi_dims: Optional[Dict[str, tuple]] = field(
         init=False, default_factory=lambda: {}
@@ -124,7 +133,6 @@ class CziMetadata:
     microscope: Optional[CziMicroscope] = field(init=False, default=None)
     sample: Optional[CziSampleInfo] = field(init=False, default=None)
     add_metadata: Optional[CziAddMetaData] = field(init=False, default=None)
-    array6d_size: Optional[Tuple[int]] = field(init=False, default_factory=lambda: ())
     scene_size_consistent: Optional[Tuple[int]] = field(
         init=False, default_factory=lambda: ()
     )
@@ -400,7 +408,6 @@ def create_md_dict_red(
         "SizeH": metadata.image.SizeH,
         "SizeI": metadata.image.SizeI,
         "isRGB": metadata.isRGB,
-        "array6d_size": metadata.array6d_size,
         "has_scenes": metadata.has_scenes,
         "has_label": metadata.attachments.has_label,
         "has_preview": metadata.attachments.has_preview,
@@ -417,8 +424,10 @@ def create_md_dict_red(
         "ScaleRatio_XYZ": metadata.scale.ratio,
         "ChannelNames": metadata.channelinfo.names,
         "ChannelDyes": metadata.channelinfo.dyes,
+        "ChannelDyesShort": metadata.channelinfo.dyes_short,
         "ChannelColors": metadata.channelinfo.colors,
         "WellArrayNames": metadata.sample.well_array_names,
+        "ChannelDescriptions": metadata.channelinfo.channel_descriptions,
         "WellIndicies": metadata.sample.well_indices,
         "WellPositionNames": metadata.sample.well_position_names,
         "WellRowID": metadata.sample.well_rowID,
@@ -431,6 +440,10 @@ def create_md_dict_red(
         "TotalBoundingBox": metadata.bbox.total_bounding_box,
     }
 
+    # Convert all numpy values to native Python types for better display
+    with contextlib.suppress(Exception):  # Catch any conversion errors
+        md_dict = convert_numpy_types(md_dict)
+
     # check for extra entries when reading mosaic file with a scale factor
     if hasattr(metadata.image, "SizeX_sf"):
         md_dict["XScale_sf"] = metadata.scale.X_sf
@@ -441,7 +454,8 @@ def create_md_dict_red(
         md_dict["SizeY_scene"] = metadata.image.SizeY_scene
 
     if remove_none:
-        md_dict = misc.remove_none_from_dict(md_dict)
+        # md_dict = misc.remove_none_from_dict(md_dict)
+        md_dict = misc.clean_dict(md_dict)
 
     if sort:
         return misc.sort_dict_by_key(md_dict)
@@ -464,8 +478,6 @@ def create_md_dict_nested(
         Dict: Nested dictionary with reduced set of metadata_tools
     """
 
-    md_array6d = {"array6d": metadata.array6d_size}
-
     md_box_image = Box(asdict(metadata.image))
     del md_box_image.czisource
 
@@ -507,7 +519,6 @@ def create_md_dict_nested(
     md_box_image += md_box_image_add
 
     IDs = [
-        "array6d",
         "image",
         "scale",
         "sample",
@@ -518,7 +529,6 @@ def create_md_dict_nested(
     ]
 
     mds = [
-        md_array6d,
         md_box_image.to_dict(),
         md_box_scale.to_dict(),
         md_box_sample.to_dict(),
@@ -531,7 +541,8 @@ def create_md_dict_nested(
     md_dict = dict(zip(IDs, mds))
 
     if remove_none:
-        md_dict = misc.remove_none_from_dict(md_dict)
+        # md_dict = misc.remove_none_from_dict(md_dict)
+        md_dict = misc.clean_dict(md_dict)
 
     if sort:
         return misc.sort_dict_by_key(md_dict)
@@ -539,3 +550,31 @@ def create_md_dict_nested(
         return md_dict
 
     return md_dict
+
+
+def convert_numpy_types(obj: Any) -> Any:
+    """
+    Recursively convert numpy types to native Python types.
+
+    This function handles numpy scalars, arrays, dictionaries, lists, and tuples.
+    It converts numpy scalars to their native Python equivalents, numpy arrays
+    to Python lists, and recursively processes dictionaries, lists, and tuples.
+
+    Args:
+        obj (Any): The object to convert. Can be a numpy scalar, numpy array,
+                   dictionary, list, tuple, or any other type.
+
+    Returns:
+        Any: The converted object with numpy types replaced by native Python types.
+    """
+    if hasattr(obj, "dtype"):  # numpy scalar or array
+        if obj.ndim == 0:  # scalar
+            return obj.item()  # Convert to native Python type
+        else:
+            return obj.tolist()  # Convert array to list
+    elif isinstance(obj, dict):
+        return {key: convert_numpy_types(value) for key, value in obj.items()}
+    elif isinstance(obj, (list, tuple)):
+        return type(obj)(convert_numpy_types(item) for item in obj)
+    else:
+        return obj
