@@ -9,7 +9,7 @@
 #
 #################################################################
 
-from typing import Dict, Tuple, Optional, Union, Annotated, List
+from typing import Dict, Tuple, Optional, Union, List
 from pylibCZIrw import czi as pyczi
 from aicspylibczi import CziFile
 from czitools.metadata_tools import czi_metadata as czimd
@@ -24,8 +24,8 @@ from tqdm.contrib.itertools import product
 import tempfile
 import shutil
 from czitools.utils import logging_tools
-from czitools.metadata_tools.helper import ValueRange
 from czitools.metadata_tools.helper import AttachmentType
+import xarray as xr
 
 # from memory_profiler import profile
 
@@ -37,27 +37,28 @@ logger = logging_tools.set_logging()
 # @profile
 def read_6darray(
     filepath: Union[str, os.PathLike[str]],
-    use_dask: bool = False,
-    chunk_zyx: bool = False,
-    planes: Dict[str, tuple[int, int]] = {},
-    zoom: Annotated[float, ValueRange(0.01, 1.0)] = 1.0,
-) -> Tuple[Optional[Union[np.ndarray, da.Array]], czimd.CziMetadata]:
+    use_dask: Optional[bool] = False,
+    chunk_zyx: Optional[bool] = False,
+    planes: Optional[Dict[str, Tuple[int, int]]] = None,
+    zoom: Optional[float] = 1.0,
+    use_xarray: Optional[bool] = True,
+) -> Tuple[Optional[Union[np.ndarray, da.Array, xr.DataArray]], czimd.CziMetadata]:
     """Read a CZI image file as 6D dask array.
     Important: Currently supported are only scenes with equal size and CZIs with consistent pixel types.
     The output array has always the dimension order: STCZYX(A)
 
     Args:
         filepath (str | Path): filepath for the CZI image
-        use_dask (bool, optional): Option to store image data as dask array with delayed reading
-        chunk_zyx (bool, optional): Option to chunk dask array along z-stacks. Defaults to False.
-        zoom (float, optional): Downscale images using a factor [0.01 - 1.0]. Defaults to 1.0
-        planes (dict, optional): Allowed keys S, T, Z, C and their start and end values must be >=0 (zero-based).
+        use_dask (Optional[bool], optional): Option to store image data as dask array with delayed reading. Defaults to False.
+        chunk_zyx (Optional[bool], optional): Option to chunk dask array along z-stacks. Defaults to False.
+        planes (Optional[Dict[str, Tuple[int, int]]], optional): Allowed keys S, T, Z, C and their start and end values must be >=0 (zero-based).
                                  planes = {"Z":(0, 2)} will return 3 z-plane with indices (0, 1, 2).
-                                 Respectively {"Z":(5, 5)} will return a single z-plane with index 5.
-        zoom (float, options): Downsample CZI image by a factor [0.01 - 1.0]. Defaults to 1.0.
+                                 Respectively {"Z":(5, 5)} will return a single z-plane with index 5. Defaults to None.
+        zoom (Optional[float], optional): Downscale images using a factor [0.01 - 1.0]. Defaults to 1.0.
+        use_xarray (Optional[bool], optional): Option to use xarray for the output array. Defaults to True.
 
     Returns:
-        Tuple[array6d, mdata]: output as 6D dask array and metadata_tools
+        Tuple[array6d, mdata]: output as 6D numpy, dask or xarray and metadata_tools
     """
 
     if isinstance(filepath, Path):
@@ -67,6 +68,9 @@ def read_6darray(
     # check zoom factor for valid range
     zoom = misc.check_zoom(zoom=zoom)
 
+    # define used dimensions
+    dims = ("S", "T", "C", "Z", "Y", "X", "A")
+
     # get the complete metadata_tools at once as one big class
     mdata = czimd.CziMetadata(filepath)
 
@@ -80,8 +84,7 @@ def read_6darray(
     mdata.scale.ratio["zx_sf"] = np.round(mdata.scale.Z / mdata.scale.X_sf, 3)
 
     # check planes
-    # if not planes is False:
-    if planes is not False:
+    if planes:
         for k in ["S", "T", "C", "Z"]:
             if k in planes.keys() and k in mdata.bbox.total_bounding_box.keys():
                 if mdata.bbox.total_bounding_box[k][1] - 1 < planes[k][1]:
@@ -94,24 +97,12 @@ def read_6darray(
         # use pixel type from first channel
         use_pixeltype = mdata.npdtype_list[0]
 
-    if not mdata.scene_shape_is_consistent and "S" not in planes.keys():
+    if not mdata.scene_shape_is_consistent and "S" not in (planes or {}):
         logger.info("Scenes have inconsistent shape. Cannot read 6D array")
         return None, mdata
 
     # open the CZI document to read the
     with pyczi.open_czi(filepath, mdata.pyczi_readertype) as czidoc:
-        # if mdata.image.SizeS is not None:
-        #     # get size for a single scene using the 1st
-        #     # works only if scene shape is consistent
-
-        #     # use the size of the 1st scenes_bounding_rectangle
-        #     size_x = czidoc.scenes_bounding_rectangle[0].w
-        #     size_y = czidoc.scenes_bounding_rectangle[0].h
-
-        # if mdata.image.SizeS is None:
-        #     # use the size of the total_bounding_rectangle
-        #     size_x = czidoc.total_bounding_rectangle.w
-        #     size_y = czidoc.total_bounding_rectangle.h
 
         # check if dimensions are None (because they do not exist for that image)
         size_c = misc.check_dimsize(mdata.image.SizeC, set2value=1)
@@ -129,29 +120,25 @@ def read_6darray(
         z_end = size_z
 
         # check for additional arguments to create substacks
-        if (
-            planes is not False
-            and mdata.image.SizeS is not None
-            and "S" in planes.keys()
-        ):
+        if planes and mdata.image.SizeS is not None and "S" in planes.keys():
             size_s = planes["S"][1] - planes["S"][0] + 1
             mdata.image.SizeS = size_s
             s_start = planes["S"][0]
             s_end = planes["S"][1] + 1
 
-        if planes is not False and "T" in planes.keys():
+        if planes and mdata.image.SizeT is not None and "T" in planes.keys():
             size_t = planes["T"][1] - planes["T"][0] + 1
             mdata.image.SizeT = size_t
             t_start = planes["T"][0]
             t_end = planes["T"][1] + 1
 
-        if planes is not False and "Z" in planes.keys():
+        if planes and mdata.image.SizeZ is not None and "Z" in planes.keys():
             size_z = planes["Z"][1] - planes["Z"][0] + 1
             mdata.image.SizeZ = size_z
             z_start = planes["Z"][0]
             z_end = planes["Z"][1] + 1
 
-        if planes is not False and "C" in planes.keys():
+        if planes and mdata.image.SizeC is not None and "C" in planes.keys():
             size_c = planes["C"][1] - planes["C"][0] + 1
             mdata.image.SizeC = size_c
             c_start = planes["C"][0]
@@ -181,13 +168,9 @@ def read_6darray(
 
             # read a 2D image plane from the CZI
             if mdata.image.SizeS is None:
-                image2d = czidoc.read(
-                    plane={"T": t[1], "Z": z[1], "C": c[1]}, zoom=zoom
-                )
+                image2d = czidoc.read(plane={"T": t[1], "Z": z[1], "C": c[1]}, zoom=zoom)
             else:
-                image2d = czidoc.read(
-                    plane={"T": t[1], "Z": z[1], "C": c[1]}, scene=s[1], zoom=zoom
-                )
+                image2d = czidoc.read(plane={"T": t[1], "Z": z[1], "C": c[1]}, scene=s[1], zoom=zoom)
 
             if planecount == 1:
                 # allocate array based on the expected size incl. down scaling
@@ -215,24 +198,39 @@ def read_6darray(
         # remove the A dimension
         if remove_adim:
             array6d = np.squeeze(array6d, axis=-1)
-            # dim_string = dim_string.replace("A", "")
+            dims = ("S", "T", "C", "Z", "Y", "X")
 
             if use_dask and chunk_zyx:
-                # for testing
-                array6d = array6d.rechunk(
-                    chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1])
-                )
+                # re-chunk array based on shape
+                array6d = array6d.rechunk(chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1]))
 
         if not remove_adim:
             if use_dask and chunk_zyx:
-                # for testing
-                array6d = array6d.rechunk(
-                    chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1], 3)
-                )
+                # re-chunk array based on shape
+                array6d = array6d.rechunk(chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1], 3))
 
     # update metadata_tools
     mdata.array6d_size = array6d.shape
 
+    if use_xarray:
+
+        # create xarray from array6d
+        coords = {}
+        for index, dim in enumerate(dims):
+            # Create a range for each dimension
+            coords[dim] = range(array6d.shape[index])
+
+        # Create the xarray.DataArray
+        array6d = xr.DataArray(array6d, dims=dims, coords=coords)
+
+        # Set attributes for the DataArray
+        array6d.attrs = {
+            "description": "6D image data from CZI file",
+            "source": mdata.filepath,
+            "axes": "".join(dims),
+            # "metadata": mdata,  # Include metadata if it's a dictionary or serializable
+        }
+
     return array6d, mdata
 
 
@@ -242,8 +240,8 @@ def read_6darray(
 def read_6darray_lazy(
     filepath: Union[str, os.PathLike[str]],
     chunk_zyx=False,
-    planes: Dict[str, tuple[int, int]] = {},
-    zoom: Annotated[float, ValueRange(0.01, 1.0)] = 1.0,
+    planes: Optional[Dict[str, Tuple[int, int]]] = None,
+    zoom: Optional[float] = 1.0,
 ) -> Tuple[Optional[Union[np.ndarray, da.Array]], czimd.CziMetadata]:
     """Read a CZI image file as 6D dask array with delayed plane reading.
     Important: Currently supported are only scenes with equal size and CZIs with consistent pixel types.
@@ -269,7 +267,7 @@ def read_6darray_lazy(
     mdata = czimd.CziMetadata(filepath)
 
     if not mdata.consistent_pixeltypes:
-        logger.info("Detected PixelTypes ar not consistent. Cannot create array6d")
+        logger.info("Detected PixelTypes are not consistent. Cannot create array6d")
         return None, mdata
 
     # check zoom factor for valid range
@@ -281,7 +279,7 @@ def read_6darray_lazy(
     mdata.scale.ratio["zx_sf"] = np.round(mdata.scale.Z / mdata.scale.X_sf, 3)
 
     # check planes
-    if planes is not False:
+    if planes:
         for k in ["S", "T", "C", "Z"]:
             if k in planes.keys() and k in mdata.bbox.total_bounding_box.keys():
                 if mdata.bbox.total_bounding_box[k][1] - 1 < planes[k][1]:
@@ -290,21 +288,17 @@ def read_6darray_lazy(
                     )
                     return None, mdata
 
-    if not mdata.scene_shape_is_consistent and "S" not in planes.keys():
+    if not mdata.scene_shape_is_consistent and "S" not in (planes or {}):
         logger.info("Scenes have inconsistent shape. Cannot read 6D array")
         return None, mdata
 
-    # open the CZI document to read the
+    # open the CZI document to read
     with pyczi.open_czi(filepath, mdata.pyczi_readertype) as czidoc:
         if mdata.image.SizeS is not None:
-            # get size for a single scene using the 1st
-            # works only if scene shape is consistent
-
             # use the size of the 1st scenes_bounding_rectangle
             size_x = czidoc.scenes_bounding_rectangle[0].w
             size_y = czidoc.scenes_bounding_rectangle[0].h
-
-        if mdata.image.SizeS is None:
+        else:
             # use the size of the total_bounding_rectangle
             size_x = czidoc.total_bounding_rectangle.w
             size_y = czidoc.total_bounding_rectangle.h
@@ -315,85 +309,69 @@ def read_6darray_lazy(
         size_t = misc.check_dimsize(mdata.image.SizeT, set2value=1)
         size_s = misc.check_dimsize(mdata.image.SizeS, set2value=1)
 
-        s_start = 0
-        s_end = size_s
-        t_start = 0
-        t_end = size_t
-        c_start = 0
-        c_end = size_c
-        z_start = 0
-        z_end = size_z
+        s_start, s_end = 0, size_s
+        t_start, t_end = 0, size_t
+        c_start, c_end = 0, size_c
+        z_start, z_end = 0, size_z
 
         # check for additional arguments to create substacks
-        if (
-            planes is not False
-            and mdata.image.SizeS is not None
-            and "S" in planes.keys()
-        ):
+        if planes and mdata.image.SizeS is not None and "S" in planes.keys():
             size_s = planes["S"][1] - planes["S"][0] + 1
             mdata.image.SizeS = size_s
             s_start = planes["S"][0]
             s_end = planes["S"][1] + 1
 
-        if planes is not False and "T" in planes.keys():
+        if planes and mdata.image.SizeT is not None and "T" in planes.keys():
             size_t = planes["T"][1] - planes["T"][0] + 1
             mdata.image.SizeT = size_t
             t_start = planes["T"][0]
             t_end = planes["T"][1] + 1
 
-        if planes is not False and "Z" in planes.keys():
+        if planes and mdata.image.SizeZ is not None and "Z" in planes.keys():
             size_z = planes["Z"][1] - planes["Z"][0] + 1
             mdata.image.SizeZ = size_z
             z_start = planes["Z"][0]
             z_end = planes["Z"][1] + 1
 
-        if planes is not False and "C" in planes.keys():
+        if planes and mdata.image.SizeC is not None and "C" in planes.keys():
             size_c = planes["C"][1] - planes["C"][0] + 1
             mdata.image.SizeC = size_c
             c_start = planes["C"][0]
             c_end = planes["C"][1] + 1
 
-        # check if ADim can be removed because image is grayscale
-        # Check if any value in the dictionary is True
+        # check if the A Dimension can be removed because image is grayscale
         contains_rgb = any(mdata.isRGB.values())
-        remove_adim = False if contains_rgb else True
+        remove_adim = not contains_rgb
 
-        if mdata.isRGB:
-            shape2d = (size_y, size_x, 3)
-        elif not mdata.isRGB:
-            shape2d = (size_y, size_x)
+        shape2d = (size_y, size_x, 3) if contains_rgb else (size_y, size_x)
 
-        # initialise empty list to hold the dask arrays
+        # initialize empty list to hold the dask arrays
         img = []
 
         with tqdm(
             total=size_s * size_t * size_c * size_z,
             desc="Reading 2D planes",
-            unit=" 2dplanes",
+            unit=" 2Dplanes",
         ) as pbar:
-            for s in enumerate(range(s_start, s_end)):
-                # for s in range(size_s):
+            for s in range(s_start, s_end):
                 time_stack = []
 
-                for time in enumerate(range(t_start, t_end)):
-                    # for time in range(size_t):
+                for t in range(t_start, t_end):
                     ch_stack = []
 
-                    for ch in enumerate(range(c_start, c_end)):
-                        # for ch in range(size_c):
+                    for c in range(c_start, c_end):
                         z_stack = []
 
-                        # for z in range(size_z):
-                        for z in enumerate(range(z_start, z_end)):
-                            # if mdata.image.SizeS is not None:
+                        for z in range(z_start, z_end):
                             z_slice = da.from_delayed(
                                 read_2dplane(
                                     czidoc,
-                                    s=s[1],
-                                    t=time[1],
-                                    c=ch[1],
-                                    z=z[1],
+                                    s=s,
+                                    t=t,
+                                    c=c,
+                                    z=z,
                                     has_scenes=mdata.has_scenes,
+                                    zoom=zoom,
                                     remove_adim=remove_adim,
                                 ),
                                 shape=shape2d,
@@ -401,55 +379,27 @@ def read_6darray_lazy(
                             )
                             pbar.update()
 
-                            # if mdata.image.SizeS is None:
-                            #     z_slice = da.from_delayed(
-                            #         read_2dplane(
-                            #             czidoc,
-                            #             s=s[1],
-                            #             t=time[1],
-                            #             c=ch[1],
-                            #             z=z[1],
-                            #             has_scenes=False,
-                            #             remove_adim=remove_adim,
-                            #         ),
-                            #         shape=shape2d,
-                            #         dtype=mdata.npdtype[0],
-                            #     )
-                            #     pbar.update()
-
-                            # create 2d array
-                            z_slice = da.squeeze(z_slice)
-
                             # append to the z-stack
                             z_stack.append(z_slice)
 
                         # stack the array and create new dask array
                         z_stack = da.stack(z_stack, axis=0)
-
-                        # create CZYX list of dask array
                         ch_stack.append(z_stack)
 
-                    # create TCZYX list of dask array
                     time_stack.append(ch_stack)
 
-                # create STCZYX list of dask array
                 img.append(time_stack)
 
             # create final STCZYX dask array
             array6d = da.stack(img, axis=0)
 
-        # dim_string = "STCZYXA"
-
         # remove the A dimension
         if remove_adim:
-            # dim_string = dim_string.replace("A", "")
             if chunk_zyx:
-                # for testing
                 array6d = array6d.rechunk(chunks=(1, 1, 1, size_z, size_y, size_x))
 
         if not remove_adim:
             if chunk_zyx:
-                # for testing
                 array6d = array6d.rechunk(chunks=(1, 1, 1, size_z, size_y, size_x, 3))
 
     return array6d, mdata
@@ -463,7 +413,7 @@ def read_2dplane(
     c: int = 0,
     z: int = 0,
     has_scenes: bool = True,
-    zoom: Annotated[float, ValueRange(0.01, 1.0)] = 1.0,
+    zoom: float = 1.0,
     remove_adim: bool = True,
 ):
     """Dask delayed function to read a 2d plane from a CZI image, which has the shape
@@ -526,9 +476,7 @@ def read_attachments(
 
         if attachment_type not in AttachmentType:
             # if attachment_type not in ["SlidePreview", "Label", "]:
-            raise Exception(
-                f"{attachment_type} is not supported. Valid types are: SlidePreview, Label or Prescan."
-            )
+            raise Exception(f"{attachment_type} is not supported. Valid types are: SlidePreview, Label or Prescan.")
 
         att = czimd.CziAttachments(czi_filepath)
 
@@ -558,12 +506,7 @@ def read_attachments(
 
                         if copy:
                             # create path to store the attachment image
-                            att_path = (
-                                str(czi_filepath)[:-4]
-                                + "_"
-                                + att.attachment_entry.name
-                                + ".czi"
-                            )
+                            att_path = str(czi_filepath)[:-4] + "_" + att.attachment_entry.name + ".czi"
 
                             # copy the file
                             dest = shutil.copyfile(full_path, att_path)
@@ -578,16 +521,12 @@ def read_attachments(
                             return img2d
 
     except ImportError:  # as e:
-        logger.warning(
-            "Package czifile not found. Cannot extract information about attached images."
-        )
+        logger.warning("Package czifile not found. Cannot extract information about attached images.")
 
         return None, None
 
 
-def read_tiles(
-    filepath: Union[str, os.PathLike[str]], scene: int, tile: int, **kwargs
-) -> Tuple[np.ndarray, List]:
+def read_tiles(filepath: Union[str, os.PathLike[str]], scene: int, tile: int, **kwargs) -> Tuple[np.ndarray, List]:
     """
     Reads a specific tile from a CZI file.
     Parameters:
@@ -651,218 +590,3 @@ def read_tiles(
         tile_stack, size = czi.read_image(S=scene, **kwargs)
 
     return tile_stack, size
-
-
-##### EXPERIMENTAL - Do not USE
-
-
-def read_6darray_lazy2(
-    filepath: Union[str, os.PathLike[str]],
-    chunk_zyx: bool = False,
-    planes: Dict[str, tuple[int, int]] = {},
-) -> Tuple[Optional[Union[np.ndarray, da.Array]], czimd.CziMetadata]:
-    """Read a CZI image file as 6D dask array.
-    Important: Currently supported are only scenes with equal size and CZIs with consistent pixel types.
-    The output array has always the dimension order: STCZYX(A)
-
-    Args:
-        filepath (str | Path): filepath for the CZI image
-        chunk_zyx (bool, optional): Option to chunk dask array along z-stacks. Defaults to False.
-        planes (dict, optional): Allowed keys S, T, Z, C and their start and end values must be >=0 (zero-based).
-                                 planes = {"Z":(0, 2)} will return 3 z-plane with indices (0, 1, 2).
-                                 Respectively {"Z":(5, 5)} will return a single z-plane with index 5.
-        zoom (float, options): Downsample CZI image by a factor [0.01 - 1.0]. Defaults to 1.0.
-
-    Returns:
-        Tuple[array6d, mdata]: output as 6D lazy dask array and metadata_tools
-    """
-
-    if isinstance(filepath, Path):
-        # convert to string
-        filepath = str(filepath)
-
-    # get the complete metadata_tools at once as one big class
-    mdata = czimd.CziMetadata(filepath)
-
-    if not mdata.consistent_pixeltypes:
-        logger.info("Detected PixelTypes ar not consistent. Cannot create array6d")
-        return None, mdata
-
-    # check planes
-    # if not planes is False:
-    if planes is not False:
-        for k in ["S", "T", "C", "Z"]:
-            if k in planes.keys() and k in mdata.bbox.total_bounding_box.keys():
-                if mdata.bbox.total_bounding_box[k][1] - 1 < planes[k][1]:
-                    logger.info(
-                        f"Planes indices (zero-based) for {planes[k]} are invalid. BBox for {[k]}: {mdata.bbox.total_bounding_box[k]}"
-                    )
-                    return None, mdata
-
-    if mdata.consistent_pixeltypes:
-        # use pixel type from first channel
-        use_pixeltype = mdata.npdtype[0]
-
-    if not mdata.scene_shape_is_consistent and "S" not in planes.keys():
-        logger.info("Scenes have inconsistent shape. Cannot read 6D array")
-        return None, mdata
-
-    # open the CZI document to read the
-    with pyczi.open_czi(filepath, mdata.pyczi_readertype) as czidoc:
-
-        if mdata.image.SizeS is not None:
-            # get size for a single scene using the 1st
-            # works only if scene shape is consistent
-
-            # use the size of the 1st scenes_bounding_rectangle
-            size_x = czidoc.scenes_bounding_rectangle[0].w
-            size_y = czidoc.scenes_bounding_rectangle[0].h
-
-        if mdata.image.SizeS is None:
-            # use the size of the total_bounding_rectangle
-            size_x = czidoc.total_bounding_rectangle.w
-            size_y = czidoc.total_bounding_rectangle.h
-
-        # check if dimensions are None (because they do not exist for that image)
-        size_c = misc.check_dimsize(mdata.image.SizeC, set2value=1)
-        size_z = misc.check_dimsize(mdata.image.SizeZ, set2value=1)
-        size_t = misc.check_dimsize(mdata.image.SizeT, set2value=1)
-        size_s = misc.check_dimsize(mdata.image.SizeS, set2value=1)
-
-        s_start = 0
-        s_end = size_s
-        t_start = 0
-        t_end = size_t
-        c_start = 0
-        c_end = size_c
-        z_start = 0
-        z_end = size_z
-
-        # check for additional arguments to create substacks
-        if (
-            planes is not False
-            and mdata.image.SizeS is not None
-            and "S" in planes.keys()
-        ):
-            size_s = planes["S"][1] - planes["S"][0] + 1
-            mdata.image.SizeS = size_s
-            s_start = planes["S"][0]
-            s_end = planes["S"][1] + 1
-
-        if planes is not False and "T" in planes.keys():
-            size_t = planes["T"][1] - planes["T"][0] + 1
-            mdata.image.SizeT = size_t
-            t_start = planes["T"][0]
-            t_end = planes["T"][1] + 1
-
-        if planes is not False and "Z" in planes.keys():
-            size_z = planes["Z"][1] - planes["Z"][0] + 1
-            mdata.image.SizeZ = size_z
-            z_start = planes["Z"][0]
-            z_end = planes["Z"][1] + 1
-
-        if planes is not False and "C" in planes.keys():
-            size_c = planes["C"][1] - planes["C"][0] + 1
-            mdata.image.SizeC = size_c
-            c_start = planes["C"][0]
-            c_end = planes["C"][1] + 1
-
-        # check if ADim can be removed because image is grayscale
-        remove_adim = False if mdata.isRGB else True
-
-        if mdata.is_url:
-            logger.info("Reading pixel data via network from link location.")
-
-        shape = (
-            size_s,
-            size_t,
-            size_c,
-            size_z,
-            size_y,
-            size_x,
-            3 if mdata.isRGB else 1,
-        )
-
-        array6d = da.empty(shape, dtype=use_pixeltype, chunks=shape)
-
-        # read array for the scene 2Dplane-by-2Dplane
-        for s, time, ch, z in product(
-            enumerate(range(s_start, s_end)),
-            enumerate(range(t_start, t_end)),
-            enumerate(range(c_start, c_end)),
-            enumerate(range(z_start, z_end)),
-            desc="Reading 2D planes",
-            unit=" 2Dplanes",
-        ):
-
-            # read a 2D image plane from the CZI
-            image2d = da.from_delayed(
-                read_2dplane_2(
-                    filepath,
-                    mdata.pyczi_readertype,
-                    s=s[1],
-                    t=time[1],
-                    c=ch[1],
-                    z=z[1],
-                    has_scenes=mdata.has_scenes,
-                    remove_adim=False,
-                ),
-                shape=(size_y, size_x, 3 if mdata.isRGB else 1),
-                dtype=mdata.npdtype[0],
-            )
-
-            # insert 2D image plane into the array6d
-            array6d[s[0], time[0], ch[0], z[0], ...] = image2d
-
-        # remove the A dimension
-        if remove_adim:
-            array6d = np.squeeze(array6d, axis=-1)
-            # dim_string = dim_string.replace("A", "")
-
-            if chunk_zyx:
-                # for testing
-                array6d = array6d.rechunk(
-                    chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1])
-                )
-
-        if not remove_adim:
-            if chunk_zyx:
-                # for testing
-                array6d = array6d.rechunk(
-                    chunks=(1, 1, 1, size_z, image2d.shape[0], image2d.shape[1], 3)
-                )
-
-    # update metadata_tools
-    mdata.array6d_size = array6d.shape
-
-    return array6d, mdata
-
-
-@dask.delayed
-def read_2dplane_2(
-    filepath,
-    readertype,
-    # czidoc: pyczi.CziReader,
-    s: int = 0,
-    t: int = 0,
-    c: int = 0,
-    z: int = 0,
-    has_scenes: bool = True,
-    remove_adim: bool = True,
-):
-
-    # open the CZI document to read the
-    with pyczi.open_czi(filepath, readertype) as czidoc:
-
-        if has_scenes:
-            # read a 2d plane using the scene index
-            image2d = czidoc.read(plane={"T": t, "C": c, "Z": z}, scene=s)
-        if not has_scenes:
-            # reading a 2d plane in case the CZI has no scenes
-            image2d = czidoc.read(plane={"T": t, "C": c, "Z": z})
-
-        # remove a last "A" dimension when desired
-        if remove_adim:
-            return image2d[..., 0]
-        if not remove_adim:
-            return image2d
